# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%vdp/pipeline/v1beta/integration.proto\x12\x13vdp.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a vdp/pipeline/v1beta/common.proto\"\x80\x06\n\nConnection\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x02id\x12)\n\x0cnamespace_id\x18\x03 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05R\x0bnamespaceId\x12-\n\x0eintegration_id\x18\x04 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05R\rintegrationId\x12\x30\n\x11integration_title\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x10integrationTitle\x12\x43\n\x06method\x18\x06 \x01(\x0e\x32&.vdp.pipeline.v1beta.Connection.MethodB\x03\xe0\x41\x02R\x06method\x12\x32\n\x05setup\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\x05setup\x12\x1b\n\x06scopes\x18\x0b \x03(\tB\x03\xe0\x41\x01R\x06scopes\x12$\n\x08identity\x18\r \x01(\tB\x03\xe0\x41\x01H\x00R\x08identity\x88\x01\x01\x12T\n\x15o_auth_access_details\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01H\x01R\x12oAuthAccessDetails\x88\x01\x01\x12\x32\n\x04view\x18\x08 \x01(\x0e\x32\x19.vdp.pipeline.v1beta.ViewB\x03\xe0\x41\x03R\x04view\x12@\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\"I\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x15\n\x11METHOD_DICTIONARY\x10\x01\x12\x10\n\x0cMETHOD_OAUTH\x10\x02\x42\x0b\n\t_identityB\x18\n\x16_o_auth_access_details\"\xe3\x01\n\x1fListNamespaceConnectionsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xbb\x01\n ListNamespaceConnectionsResponse\x12\x46\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x1f.vdp.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\x0b\x63onnections\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb3\x01\n\x1dGetNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12\x37\n\x04view\x18\x03 \x01(\x0e\x32\x19.vdp.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"f\n\x1eGetNamespaceConnectionResponse\x12\x44\n\nconnection\x18\x01 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"h\n CreateNamespaceConnectionRequest\x12\x44\n\nconnection\x18\x01 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.ConnectionB\x03\xe0\x41\x02R\nconnection\"i\n!CreateNamespaceConnectionResponse\x12\x44\n\nconnection\x18\x01 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"\xd4\x01\n UpdateNamespaceConnectionRequest\x12(\n\rconnection_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12\x44\n\nconnection\x18\x02 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.ConnectionB\x03\xe0\x41\x02R\nconnection\x12@\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"i\n!UpdateNamespaceConnectionResponse\x12\x44\n\nconnection\x18\x01 \x01(\x0b\x32\x1f.vdp.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"t\n DeleteNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\"#\n!DeleteNamespaceConnectionResponse\"r\n\x1eTestNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\"!\n\x1fTestNamespaceConnectionResponse\"\xf6\x06\n\x0bIntegration\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x19\n\x05title\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x05title\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x1b\n\x06vendor\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x06vendor\x12\x17\n\x04icon\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x04icon\x12L\n\thelp_link\x18\x07 \x01(\x0b\x32%.vdp.pipeline.v1beta.Integration.LinkB\x03\xe0\x41\x03H\x00R\x08helpLink\x88\x01\x01\x12?\n\x0csetup_schema\x18\n \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0bsetupSchema\x12Z\n\ro_auth_config\x18\x0b \x01(\x0b\x32,.vdp.pipeline.v1beta.Integration.OAuthConfigB\x03\xe0\x41\x03H\x01R\x0boAuthConfig\x88\x01\x01\x12\x32\n\x04view\x18\t \x01(\x0e\x32\x19.vdp.pipeline.v1beta.ViewB\x03\xe0\x41\x03R\x04view\x12M\n\x07schemas\x18\x08 \x03(\x0b\x32,.vdp.pipeline.v1beta.Integration.SetupSchemaB\x05\x18\x01\xe0\x41\x03R\x07schemas\x1a\x36\n\x04Link\x12\x17\n\x04text\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04text\x12\x15\n\x03url\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03url\x1an\n\x0bOAuthConfig\x12\x1e\n\x08\x61uth_url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07\x61uthUrl\x12\"\n\naccess_url\x18\x02 \x01(\tB\x03\xe0\x41\x03R\taccessUrl\x12\x1b\n\x06scopes\x18\x0b \x03(\tB\x03\xe0\x41\x03R\x06scopes\x1a\x8c\x01\n\x0bSetupSchema\x12\x45\n\x06method\x18\x01 \x01(\x0e\x32&.vdp.pipeline.v1beta.Connection.MethodB\x05\x18\x01\xe0\x41\x03R\x06method\x12\x36\n\x06schema\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x05\x18\x01\xe0\x41\x03R\x06schemaB\x0c\n\n_help_linkB\x10\n\x0e_o_auth_config\"\x92\x02\n$ListPipelineIDsByConnectionIDRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12%\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xa0\x01\n%ListPipelineIDsByConnectionIDResponse\x12&\n\x0cpipeline_ids\x18\x01 \x03(\tB\x03\xe0\x41\x03R\x0bpipelineIds\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb3\x01\n\x17ListIntegrationsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xb6\x01\n\x18ListIntegrationsResponse\x12I\n\x0cintegrations\x18\x01 \x03(\x0b\x32 .vdp.pipeline.v1beta.IntegrationB\x03\xe0\x41\x03R\x0cintegrations\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\x85\x01\n\x15GetIntegrationRequest\x12*\n\x0eintegration_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\rintegrationId\x12\x37\n\x04view\x18\x02 \x01(\x0e\x32\x19.vdp.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"a\n\x16GetIntegrationResponse\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32 .vdp.pipeline.v1beta.IntegrationB\x03\xe0\x41\x03R\x0bintegrationB\xdf\x01\n\x17\x63om.vdp.pipeline.v1betaB\x10IntegrationProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\020IntegrationProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _CONNECTION.fields_by_name['uid']._options = None
  _CONNECTION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['id']._options = None
  _CONNECTION.fields_by_name['id']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['namespace_id']._options = None
  _CONNECTION.fields_by_name['namespace_id']._serialized_options = b'\340A\002\340A\005'
  _CONNECTION.fields_by_name['integration_id']._options = None
  _CONNECTION.fields_by_name['integration_id']._serialized_options = b'\340A\002\340A\005'
  _CONNECTION.fields_by_name['integration_title']._options = None
  _CONNECTION.fields_by_name['integration_title']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['method']._options = None
  _CONNECTION.fields_by_name['method']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['setup']._options = None
  _CONNECTION.fields_by_name['setup']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['scopes']._options = None
  _CONNECTION.fields_by_name['scopes']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['identity']._options = None
  _CONNECTION.fields_by_name['identity']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['o_auth_access_details']._options = None
  _CONNECTION.fields_by_name['o_auth_access_details']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['view']._options = None
  _CONNECTION.fields_by_name['view']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['create_time']._options = None
  _CONNECTION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['update_time']._options = None
  _CONNECTION.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['connections']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['connections']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _GETNAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._options = None
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _CREATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _CREATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _UPDATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _INTEGRATION_LINK.fields_by_name['text']._options = None
  _INTEGRATION_LINK.fields_by_name['text']._serialized_options = b'\340A\003'
  _INTEGRATION_LINK.fields_by_name['url']._options = None
  _INTEGRATION_LINK.fields_by_name['url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['auth_url']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['auth_url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['access_url']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['access_url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['scopes']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['scopes']._serialized_options = b'\340A\003'
  _INTEGRATION_SETUPSCHEMA.fields_by_name['method']._options = None
  _INTEGRATION_SETUPSCHEMA.fields_by_name['method']._serialized_options = b'\030\001\340A\003'
  _INTEGRATION_SETUPSCHEMA.fields_by_name['schema']._options = None
  _INTEGRATION_SETUPSCHEMA.fields_by_name['schema']._serialized_options = b'\030\001\340A\003'
  _INTEGRATION.fields_by_name['uid']._options = None
  _INTEGRATION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['id']._options = None
  _INTEGRATION.fields_by_name['id']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['title']._options = None
  _INTEGRATION.fields_by_name['title']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['description']._options = None
  _INTEGRATION.fields_by_name['description']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['vendor']._options = None
  _INTEGRATION.fields_by_name['vendor']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['icon']._options = None
  _INTEGRATION.fields_by_name['icon']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['help_link']._options = None
  _INTEGRATION.fields_by_name['help_link']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['setup_schema']._options = None
  _INTEGRATION.fields_by_name['setup_schema']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['o_auth_config']._options = None
  _INTEGRATION.fields_by_name['o_auth_config']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['view']._options = None
  _INTEGRATION.fields_by_name['view']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['schemas']._options = None
  _INTEGRATION.fields_by_name['schemas']._serialized_options = b'\030\001\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['namespace_id']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['connection_id']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['pipeline_ids']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['pipeline_ids']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['total_size']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['integrations']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['integrations']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETINTEGRATIONREQUEST.fields_by_name['integration_id']._options = None
  _GETINTEGRATIONREQUEST.fields_by_name['integration_id']._serialized_options = b'\340A\002'
  _GETINTEGRATIONREQUEST.fields_by_name['view']._options = None
  _GETINTEGRATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETINTEGRATIONRESPONSE.fields_by_name['integration']._options = None
  _GETINTEGRATIONRESPONSE.fields_by_name['integration']._serialized_options = b'\340A\003'
  _globals['_CONNECTION']._serialized_start=227
  _globals['_CONNECTION']._serialized_end=995
  _globals['_CONNECTION_METHOD']._serialized_start=883
  _globals['_CONNECTION_METHOD']._serialized_end=956
  _globals['_LISTNAMESPACECONNECTIONSREQUEST']._serialized_start=998
  _globals['_LISTNAMESPACECONNECTIONSREQUEST']._serialized_end=1225
  _globals['_LISTNAMESPACECONNECTIONSRESPONSE']._serialized_start=1228
  _globals['_LISTNAMESPACECONNECTIONSRESPONSE']._serialized_end=1415
  _globals['_GETNAMESPACECONNECTIONREQUEST']._serialized_start=1418
  _globals['_GETNAMESPACECONNECTIONREQUEST']._serialized_end=1597
  _globals['_GETNAMESPACECONNECTIONRESPONSE']._serialized_start=1599
  _globals['_GETNAMESPACECONNECTIONRESPONSE']._serialized_end=1701
  _globals['_CREATENAMESPACECONNECTIONREQUEST']._serialized_start=1703
  _globals['_CREATENAMESPACECONNECTIONREQUEST']._serialized_end=1807
  _globals['_CREATENAMESPACECONNECTIONRESPONSE']._serialized_start=1809
  _globals['_CREATENAMESPACECONNECTIONRESPONSE']._serialized_end=1914
  _globals['_UPDATENAMESPACECONNECTIONREQUEST']._serialized_start=1917
  _globals['_UPDATENAMESPACECONNECTIONREQUEST']._serialized_end=2129
  _globals['_UPDATENAMESPACECONNECTIONRESPONSE']._serialized_start=2131
  _globals['_UPDATENAMESPACECONNECTIONRESPONSE']._serialized_end=2236
  _globals['_DELETENAMESPACECONNECTIONREQUEST']._serialized_start=2238
  _globals['_DELETENAMESPACECONNECTIONREQUEST']._serialized_end=2354
  _globals['_DELETENAMESPACECONNECTIONRESPONSE']._serialized_start=2356
  _globals['_DELETENAMESPACECONNECTIONRESPONSE']._serialized_end=2391
  _globals['_TESTNAMESPACECONNECTIONREQUEST']._serialized_start=2393
  _globals['_TESTNAMESPACECONNECTIONREQUEST']._serialized_end=2507
  _globals['_TESTNAMESPACECONNECTIONRESPONSE']._serialized_start=2509
  _globals['_TESTNAMESPACECONNECTIONRESPONSE']._serialized_end=2542
  _globals['_INTEGRATION']._serialized_start=2545
  _globals['_INTEGRATION']._serialized_end=3431
  _globals['_INTEGRATION_LINK']._serialized_start=3090
  _globals['_INTEGRATION_LINK']._serialized_end=3144
  _globals['_INTEGRATION_OAUTHCONFIG']._serialized_start=3146
  _globals['_INTEGRATION_OAUTHCONFIG']._serialized_end=3256
  _globals['_INTEGRATION_SETUPSCHEMA']._serialized_start=3259
  _globals['_INTEGRATION_SETUPSCHEMA']._serialized_end=3399
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDREQUEST']._serialized_start=3434
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDREQUEST']._serialized_end=3708
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDRESPONSE']._serialized_start=3711
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDRESPONSE']._serialized_end=3871
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_start=3874
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_end=4053
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_start=4056
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_end=4238
  _globals['_GETINTEGRATIONREQUEST']._serialized_start=4241
  _globals['_GETINTEGRATIONREQUEST']._serialized_end=4374
  _globals['_GETINTEGRATIONRESPONSE']._serialized_start=4376
  _globals['_GETINTEGRATIONRESPONSE']._serialized_end=4473
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Object(google.protobuf.message.Message):
    """Object"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    NAMESPACE_UID_FIELD_NUMBER: builtins.int
    CREATOR_FIELD_NUMBER: builtins.int
    IS_UPLOADED_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    OBJECT_EXPIRE_DAYS_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_TIME_FIELD_NUMBER: builtins.int
    CREATED_TIME_FIELD_NUMBER: builtins.int
    UPDATED_TIME_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """uid"""
    name: builtins.str
    """name of the object"""
    size: builtins.int
    """size in bytes"""
    content_type: builtins.str
    """content type
    this is mime type from content-type header of http request or from file extension
    """
    namespace_uid: builtins.str
    """namespace uid"""
    creator: builtins.str
    """creator"""
    is_uploaded: builtins.bool
    """if file is uploaded"""
    path: builtins.str
    """object path(optional)"""
    object_expire_days: builtins.int
    """object live time in days
    if set to 0, the object will not be deleted automatically
    """
    @property
    def last_modified_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """last modified time"""
    @property
    def created_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """created time"""
    @property
    def updated_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """updated time"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.int = ...,
        content_type: builtins.str = ...,
        namespace_uid: builtins.str = ...,
        creator: builtins.str = ...,
        is_uploaded: builtins.bool = ...,
        path: builtins.str | None = ...,
        object_expire_days: builtins.int = ...,
        last_modified_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_last_modified_time", b"_last_modified_time", "_path", b"_path", "created_time", b"created_time", "last_modified_time", b"last_modified_time", "path", b"path", "updated_time", b"updated_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_last_modified_time", b"_last_modified_time", "_path", b"_path", "content_type", b"content_type", "created_time", b"created_time", "creator", b"creator", "is_uploaded", b"is_uploaded", "last_modified_time", b"last_modified_time", "name", b"name", "namespace_uid", b"namespace_uid", "object_expire_days", b"object_expire_days", "path", b"path", "size", b"size", "uid", b"uid", "updated_time", b"updated_time"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_last_modified_time", b"_last_modified_time"]) -> typing_extensions.Literal["last_modified_time"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_path", b"_path"]) -> typing_extensions.Literal["path"] | None: ...

global___Object = Object

@typing_extensions.final
class GetObjectUploadURLRequest(google.protobuf.message.Message):
    """GetObjectUploadURLRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    OBJECT_NAME_FIELD_NUMBER: builtins.int
    URL_EXPIRE_DAYS_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_TIME_FIELD_NUMBER: builtins.int
    OBJECT_EXPIRE_DAYS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """id of the namespace"""
    object_name: builtins.str
    """name of the object with length limit to 1024 characters.
    this is the unique identifier of the object in the namespace
    """
    url_expire_days: builtins.int
    """Expiration time in days for the URL.
    Minimum is 1 day and maximum is 7 days. If not set or set to 0, defaults to 1 day.
    """
    @property
    def last_modified_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """last modified time this value is provided by the client when the object url is created
        it must be in RFC3339 formatted date-time string
        """
    object_expire_days: builtins.int
    """object live time in days
    minimum is 1 day. if set to 0, the object will not be deleted automatically
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        object_name: builtins.str = ...,
        url_expire_days: builtins.int = ...,
        last_modified_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        object_expire_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_modified_time", b"last_modified_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_modified_time", b"last_modified_time", "namespace_id", b"namespace_id", "object_expire_days", b"object_expire_days", "object_name", b"object_name", "url_expire_days", b"url_expire_days"]) -> None: ...

global___GetObjectUploadURLRequest = GetObjectUploadURLRequest

@typing_extensions.final
class GetObjectUploadURLResponse(google.protobuf.message.Message):
    """GetObjectUploadURLResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    URL_EXPIRE_AT_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """upload url"""
    @property
    def url_expire_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """expire at in UTC (UTC+0)"""
    @property
    def object(self) -> global___Object:
        """object"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
        url_expire_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        object: global___Object | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object", b"object", "url_expire_at", b"url_expire_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["object", b"object", "upload_url", b"upload_url", "url_expire_at", b"url_expire_at"]) -> None: ...

global___GetObjectUploadURLResponse = GetObjectUploadURLResponse

@typing_extensions.final
class GetObjectDownloadURLRequest(google.protobuf.message.Message):
    """GetObjectDownloadURLRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    OBJECT_UID_FIELD_NUMBER: builtins.int
    OBJECT_NAME_FIELD_NUMBER: builtins.int
    URL_EXPIRE_DAYS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """id of the namespace"""
    object_uid: builtins.str
    """uid of the object
    if provided, object name is not required
    uid has priority over name
    """
    object_name: builtins.str
    """object name
    if provided, object uid is not required
    """
    url_expire_days: builtins.int
    """Expiration time in days for the URL.
    Minimum is 1 day and maximum is 7 days. If not set or set to 0, defaults to 1 day.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        object_uid: builtins.str = ...,
        object_name: builtins.str = ...,
        url_expire_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id", "object_name", b"object_name", "object_uid", b"object_uid", "url_expire_days", b"url_expire_days"]) -> None: ...

global___GetObjectDownloadURLRequest = GetObjectDownloadURLRequest

@typing_extensions.final
class GetObjectDownloadURLResponse(google.protobuf.message.Message):
    """GetObjectDownloadURLResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    URL_EXPIRE_AT_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    """download url"""
    @property
    def url_expire_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """expire at in UTC (UTC+0)"""
    @property
    def object(self) -> global___Object:
        """object"""
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
        url_expire_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        object: global___Object | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object", b"object", "url_expire_at", b"url_expire_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url", "object", b"object", "url_expire_at", b"url_expire_at"]) -> None: ...

global___GetObjectDownloadURLResponse = GetObjectDownloadURLResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import grpc.aio
import model.model.v1alpha.model_definition_pb2
import model.model.v1alpha.model_pb2
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ModelPublicServiceStub:
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LivenessRequest,
        model.model.v1alpha.model_pb2.LivenessResponse,
    ]
    """Check if the model server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ReadinessRequest,
        model.model.v1alpha.model_pb2.ReadinessResponse,
    ]
    """Check if the model server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    ListModelDefinitions: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsRequest,
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse,
    ]
    """List model definitions

    Returns a paginated list of model definitions.
    """
    ListAvailableRegions: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListAvailableRegionsRequest,
        model.model.v1alpha.model_pb2.ListAvailableRegionsResponse,
    ]
    """List available regions

    Returns a paginated list of available regions.
    """
    GetModelDefinition: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionRequest,
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse,
    ]
    """Get a model definition

    Returns the details of a model definition.
    """
    ListModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelsRequest,
        model.model.v1alpha.model_pb2.ListModelsResponse,
    ]
    """List models

    Returns a paginated list of models.
    """
    LookUpModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LookUpModelRequest,
        model.model.v1alpha.model_pb2.LookUpModelResponse,
    ]
    """Get a model by UID

    Returns the details of a model by a permalink defined by the resource UID.
    """
    ListNamespaceModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListNamespaceModelsRequest,
        model.model.v1alpha.model_pb2.ListNamespaceModelsResponse,
    ]
    """List namespace models

    Returns a paginated list of models.
    """
    CreateNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateNamespaceModelRequest,
        model.model.v1alpha.model_pb2.CreateNamespaceModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of a namespace. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    GetNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetNamespaceModelRequest,
        model.model.v1alpha.model_pb2.GetNamespaceModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent namespace.
    """
    UpdateNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateNamespaceModelRequest,
        model.model.v1alpha.model_pb2.UpdateNamespaceModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent namespace and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteNamespaceModelRequest,
        model.model.v1alpha.model_pb2.DeleteNamespaceModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent namespace and the ID of the model.
    """
    RenameNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameNamespaceModelRequest,
        model.model.v1alpha.model_pb2.RenameNamespaceModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent namespace and the ID of the model.
    """
    WatchNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchNamespaceModelRequest,
        model.model.v1alpha.model_pb2.WatchNamespaceModelResponse,
    ]
    """Watch the state of a model version

    Returns the state of a model. The model resource allocation and scaling actions take some
    time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    WatchNamespaceLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchNamespaceLatestModelRequest,
        model.model.v1alpha.model_pb2.WatchNamespaceLatestModelResponse,
    ]
    """Watch the state of the latest model version

    Returns the state of the latest model version. The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    ListNamespaceModelVersions: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListNamespaceModelVersionsRequest,
        model.model.v1alpha.model_pb2.ListNamespaceModelVersionsResponse,
    ]
    """List namespace model versions

    Returns a paginated list of version of a model namespace that belong to the specified namespace.
    Contains model version and digest.
    """
    DeleteNamespaceModelVersion: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionRequest,
        model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionResponse,
    ]
    """Delete a model version

    Deletes a model version, accesing it by its resource name, which is defined by the
    parent namespace and the ID of the model, and version.
    """
    TriggerNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceModelRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceModelResponse,
    ]
    """Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerAsyncNamespaceModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerNamespaceLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelResponse,
    ]
    """Trigger model inference

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerAsyncNamespaceLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerNamespaceModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    TriggerNamespaceLatestModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers the latest deployed model version to infer the result of a set of task or
    questions, submitted as a binary file.
    """
    GetNamespaceModelOperation: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetNamespaceModelOperationRequest,
        model.model.v1alpha.model_pb2.GetNamespaceModelOperationResponse,
    ]
    """Get the details of the long-running operation from a namespace model
    with a particular version

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    GetNamespaceLatestModelOperation: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationRequest,
        model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationResponse,
    ]
    """Get the details of the latest long-running operation from a namespace model

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    GetModelOperation: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetModelOperationRequest,
        model.model.v1alpha.model_pb2.GetModelOperationResponse,
    ]
    """Get the details of a long-running operation

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    ListUserModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListUserModelsRequest,
        model.model.v1alpha.model_pb2.ListUserModelsResponse,
    ]
    """The following endpoints are all deprecated

    List user models

    Returns a paginated list of models that belong to the specified user. The
    parent user may be different from the authenticated user, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateUserModelRequest,
        model.model.v1alpha.model_pb2.CreateUserModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of a user. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    GetUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserModelRequest,
        model.model.v1alpha.model_pb2.GetUserModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent user.
    """
    UpdateUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateUserModelRequest,
        model.model.v1alpha.model_pb2.UpdateUserModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent user and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteUserModelRequest,
        model.model.v1alpha.model_pb2.DeleteUserModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    RenameUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameUserModelRequest,
        model.model.v1alpha.model_pb2.RenameUserModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    WatchUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchUserModelRequest,
        model.model.v1alpha.model_pb2.WatchUserModelResponse,
    ]
    """Watch the state of a model version

    Returns the state of a model. The model resource allocation and scaling actions take some
    time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    WatchUserLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchUserLatestModelRequest,
        model.model.v1alpha.model_pb2.WatchUserLatestModelResponse,
    ]
    """Watch the state of the latest model version

    Returns the state of the latest model version. The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    ListUserModelVersions: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListUserModelVersionsRequest,
        model.model.v1alpha.model_pb2.ListUserModelVersionsResponse,
    ]
    """List user model versions

    Returns a paginated list of version of a model namespace that belong to the specified user.
    Contains model version and digest.
    """
    DeleteUserModelVersion: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteUserModelVersionRequest,
        model.model.v1alpha.model_pb2.DeleteUserModelVersionResponse,
    ]
    """Delete a model version

    Deletes a model version, accesing it by its resource name, which is defined by the
    parent user and the ID of the model, and version.
    """
    TriggerUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerAsyncUserModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncUserModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncUserModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerUserLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerUserLatestModelResponse,
    ]
    """Trigger model inference

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerAsyncUserLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerUserModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    ListOrganizationModels: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListOrganizationModelsRequest,
        model.model.v1alpha.model_pb2.ListOrganizationModelsResponse,
    ]
    """List organization models

    Returns a paginated list of models that belong to the specified organization. The
    parent organization may be different from the authenticated organization, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.CreateOrganizationModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of an organization. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    GetOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationModelRequest,
        model.model.v1alpha.model_pb2.GetOrganizationModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent organization.
    """
    UpdateOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent organization and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteOrganizationModelRequest,
        model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    RenameOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameOrganizationModelRequest,
        model.model.v1alpha.model_pb2.RenameOrganizationModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    WatchOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchOrganizationModelRequest,
        model.model.v1alpha.model_pb2.WatchOrganizationModelResponse,
    ]
    """Watch the state of a model version

    Returns the state of a model.  The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    WatchOrganizationLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchOrganizationLatestModelRequest,
        model.model.v1alpha.model_pb2.WatchOrganizationLatestModelResponse,
    ]
    """Watch the state of the latest model version

    Returns the state of the latest model version.  The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    ListOrganizationModelVersions: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListOrganizationModelVersionsRequest,
        model.model.v1alpha.model_pb2.ListOrganizationModelVersionsResponse,
    ]
    """List organization model versions

    Returns a paginated list of version of a model namespace that belong to the specified organization.
    Contains model version and digest.
    """
    DeleteOrganizationModelVersion: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionRequest,
        model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionResponse,
    ]
    """Delete a model version

    Deletes a model version, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model, and version.
    """
    TriggerOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerAsyncOrganizationModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerOrganizationLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelResponse,
    ]
    """Trigger model inference

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerAsyncOrganizationLatestModel: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerOrganizationModelBinaryFileUpload: grpc.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    GetUserLatestModelOperation: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserLatestModelOperationRequest,
        model.model.v1alpha.model_pb2.GetUserLatestModelOperationResponse,
    ]
    """Get the details of the latest long-running operation from a user model

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    GetOrganizationLatestModelOperation: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationRequest,
        model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationResponse,
    ]
    """Get the details of the latest long-running operation from a organization model

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    ListModelRuns: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelRunsRequest,
        model.model.v1alpha.model_pb2.ListModelRunsResponse,
    ]
    """List model runs

    Returns a paginated list of model runs.
    """
    ListModelRunsByCreditOwner: grpc.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerRequest,
        model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerResponse,
    ]
    """List Model Runs of a Namespace (user or organization)

    Returns a paginated list of runs for 1 or more models. This is mainly used by credit dashboard.
    The requester can view all the runs that consumed their credits across different models.
    """

class ModelPublicServiceAsyncStub:
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LivenessRequest,
        model.model.v1alpha.model_pb2.LivenessResponse,
    ]
    """Check if the model server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ReadinessRequest,
        model.model.v1alpha.model_pb2.ReadinessResponse,
    ]
    """Check if the model server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    ListModelDefinitions: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsRequest,
        model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse,
    ]
    """List model definitions

    Returns a paginated list of model definitions.
    """
    ListAvailableRegions: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListAvailableRegionsRequest,
        model.model.v1alpha.model_pb2.ListAvailableRegionsResponse,
    ]
    """List available regions

    Returns a paginated list of available regions.
    """
    GetModelDefinition: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionRequest,
        model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse,
    ]
    """Get a model definition

    Returns the details of a model definition.
    """
    ListModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelsRequest,
        model.model.v1alpha.model_pb2.ListModelsResponse,
    ]
    """List models

    Returns a paginated list of models.
    """
    LookUpModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.LookUpModelRequest,
        model.model.v1alpha.model_pb2.LookUpModelResponse,
    ]
    """Get a model by UID

    Returns the details of a model by a permalink defined by the resource UID.
    """
    ListNamespaceModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListNamespaceModelsRequest,
        model.model.v1alpha.model_pb2.ListNamespaceModelsResponse,
    ]
    """List namespace models

    Returns a paginated list of models.
    """
    CreateNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateNamespaceModelRequest,
        model.model.v1alpha.model_pb2.CreateNamespaceModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of a namespace. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    GetNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetNamespaceModelRequest,
        model.model.v1alpha.model_pb2.GetNamespaceModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent namespace.
    """
    UpdateNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateNamespaceModelRequest,
        model.model.v1alpha.model_pb2.UpdateNamespaceModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent namespace and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteNamespaceModelRequest,
        model.model.v1alpha.model_pb2.DeleteNamespaceModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent namespace and the ID of the model.
    """
    RenameNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameNamespaceModelRequest,
        model.model.v1alpha.model_pb2.RenameNamespaceModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent namespace and the ID of the model.
    """
    WatchNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchNamespaceModelRequest,
        model.model.v1alpha.model_pb2.WatchNamespaceModelResponse,
    ]
    """Watch the state of a model version

    Returns the state of a model. The model resource allocation and scaling actions take some
    time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    WatchNamespaceLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchNamespaceLatestModelRequest,
        model.model.v1alpha.model_pb2.WatchNamespaceLatestModelResponse,
    ]
    """Watch the state of the latest model version

    Returns the state of the latest model version. The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    ListNamespaceModelVersions: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListNamespaceModelVersionsRequest,
        model.model.v1alpha.model_pb2.ListNamespaceModelVersionsResponse,
    ]
    """List namespace model versions

    Returns a paginated list of version of a model namespace that belong to the specified namespace.
    Contains model version and digest.
    """
    DeleteNamespaceModelVersion: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionRequest,
        model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionResponse,
    ]
    """Delete a model version

    Deletes a model version, accesing it by its resource name, which is defined by the
    parent namespace and the ID of the model, and version.
    """
    TriggerNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceModelRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceModelResponse,
    ]
    """Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerAsyncNamespaceModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerNamespaceLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelResponse,
    ]
    """Trigger model inference

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerAsyncNamespaceLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerNamespaceModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    TriggerNamespaceLatestModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers the latest deployed model version to infer the result of a set of task or
    questions, submitted as a binary file.
    """
    GetNamespaceModelOperation: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetNamespaceModelOperationRequest,
        model.model.v1alpha.model_pb2.GetNamespaceModelOperationResponse,
    ]
    """Get the details of the long-running operation from a namespace model
    with a particular version

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    GetNamespaceLatestModelOperation: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationRequest,
        model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationResponse,
    ]
    """Get the details of the latest long-running operation from a namespace model

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    GetModelOperation: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetModelOperationRequest,
        model.model.v1alpha.model_pb2.GetModelOperationResponse,
    ]
    """Get the details of a long-running operation

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    ListUserModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListUserModelsRequest,
        model.model.v1alpha.model_pb2.ListUserModelsResponse,
    ]
    """The following endpoints are all deprecated

    List user models

    Returns a paginated list of models that belong to the specified user. The
    parent user may be different from the authenticated user, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateUserModelRequest,
        model.model.v1alpha.model_pb2.CreateUserModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of a user. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    GetUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserModelRequest,
        model.model.v1alpha.model_pb2.GetUserModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent user.
    """
    UpdateUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateUserModelRequest,
        model.model.v1alpha.model_pb2.UpdateUserModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent user and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteUserModelRequest,
        model.model.v1alpha.model_pb2.DeleteUserModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    RenameUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameUserModelRequest,
        model.model.v1alpha.model_pb2.RenameUserModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent user and the ID of the model.
    """
    WatchUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchUserModelRequest,
        model.model.v1alpha.model_pb2.WatchUserModelResponse,
    ]
    """Watch the state of a model version

    Returns the state of a model. The model resource allocation and scaling actions take some
    time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    WatchUserLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchUserLatestModelRequest,
        model.model.v1alpha.model_pb2.WatchUserLatestModelResponse,
    ]
    """Watch the state of the latest model version

    Returns the state of the latest model version. The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    ListUserModelVersions: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListUserModelVersionsRequest,
        model.model.v1alpha.model_pb2.ListUserModelVersionsResponse,
    ]
    """List user model versions

    Returns a paginated list of version of a model namespace that belong to the specified user.
    Contains model version and digest.
    """
    DeleteUserModelVersion: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteUserModelVersionRequest,
        model.model.v1alpha.model_pb2.DeleteUserModelVersionResponse,
    ]
    """Delete a model version

    Deletes a model version, accesing it by its resource name, which is defined by the
    parent user and the ID of the model, and version.
    """
    TriggerUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerAsyncUserModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncUserModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncUserModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerUserLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerUserLatestModelResponse,
    ]
    """Trigger model inference

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerAsyncUserLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerUserModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    ListOrganizationModels: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListOrganizationModelsRequest,
        model.model.v1alpha.model_pb2.ListOrganizationModelsResponse,
    ]
    """List organization models

    Returns a paginated list of models that belong to the specified organization. The
    parent organization may be different from the authenticated organization, in which case
    the results will contain the models that are visible to the latter.
    """
    CreateOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.CreateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.CreateOrganizationModelResponse,
    ]
    """Create a new model

    Creates a new model under the parenthood of an organization. This is an
    asynchronous endpoint, i.e., the server will not wait for the model to be
    created in order to respond. Instead, it will return a response with the
    necessary information to access the result and status of the creation
    operation.
    """
    GetOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationModelRequest,
        model.model.v1alpha.model_pb2.GetOrganizationModelResponse,
    ]
    """Get a model

    Returns the detail of a model, accessing it by the model ID and its parent organization.
    """
    UpdateOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.UpdateOrganizationModelRequest,
        model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse,
    ]
    """Update a model

    Updates a model, accessing it by its resource name, which is defined by
    the parent organization and the ID of the model.

    In REST requests, only the supplied model fields will be taken into
    account when updating the resource.
    """
    DeleteOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteOrganizationModelRequest,
        model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse,
    ]
    """Delete a model

    Deletes a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    RenameOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.RenameOrganizationModelRequest,
        model.model.v1alpha.model_pb2.RenameOrganizationModelResponse,
    ]
    """Rename a model

    Renames a model, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model.
    """
    WatchOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchOrganizationModelRequest,
        model.model.v1alpha.model_pb2.WatchOrganizationModelResponse,
    ]
    """Watch the state of a model version

    Returns the state of a model.  The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    WatchOrganizationLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.WatchOrganizationLatestModelRequest,
        model.model.v1alpha.model_pb2.WatchOrganizationLatestModelResponse,
    ]
    """Watch the state of the latest model version

    Returns the state of the latest model version.  The model resource allocation and scaling actions
    take some time, during which a model will be in various state. This endpoint
    allows clients to track the state.
    """
    ListOrganizationModelVersions: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListOrganizationModelVersionsRequest,
        model.model.v1alpha.model_pb2.ListOrganizationModelVersionsResponse,
    ]
    """List organization model versions

    Returns a paginated list of version of a model namespace that belong to the specified organization.
    Contains model version and digest.
    """
    DeleteOrganizationModelVersion: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionRequest,
        model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionResponse,
    ]
    """Delete a model version

    Deletes a model version, accesing it by its resource name, which is defined by the
    parent organization and the ID of the model, and version.
    """
    TriggerOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse,
    ]
    """/////////////////////////////////////////////////////

    Trigger model inference

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerAsyncOrganizationModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers a deployed model to infer the result of a set of task or
    questions.
    """
    TriggerOrganizationLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelResponse,
    ]
    """Trigger model inference

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerAsyncOrganizationLatestModel: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelRequest,
        model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelResponse,
    ]
    """Trigger model inference asynchronously

    Triggers the latest deployed model version to infer the result of a set of task or
    questions.
    """
    TriggerOrganizationModelBinaryFileUpload: grpc.aio.StreamUnaryMultiCallable[
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadRequest,
        model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse,
    ]
    """Trigger model inference with a binary input

    Triggers a deployed model to infer the result of a task or question,
    submitted as a binary file.
    """
    GetUserLatestModelOperation: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetUserLatestModelOperationRequest,
        model.model.v1alpha.model_pb2.GetUserLatestModelOperationResponse,
    ]
    """Get the details of the latest long-running operation from a user model

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    GetOrganizationLatestModelOperation: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationRequest,
        model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationResponse,
    ]
    """Get the details of the latest long-running operation from a organization model

    This method allows requesters to request the status and outcome of
    long-running operations in a model, such as trigger.
    """
    ListModelRuns: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelRunsRequest,
        model.model.v1alpha.model_pb2.ListModelRunsResponse,
    ]
    """List model runs

    Returns a paginated list of model runs.
    """
    ListModelRunsByCreditOwner: grpc.aio.UnaryUnaryMultiCallable[
        model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerRequest,
        model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerResponse,
    ]
    """List Model Runs of a Namespace (user or organization)

    Returns a paginated list of runs for 1 or more models. This is mainly used by credit dashboard.
    The requester can view all the runs that consumed their credits across different models.
    """

class ModelPublicServiceServicer(metaclass=abc.ABCMeta):
    """Model

    ModelPublicService exposes the public endpoints that allow clients to manage
    models.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: model.model.v1alpha.model_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.LivenessResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.LivenessResponse]]:
        """Check if the model server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: model.model.v1alpha.model_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ReadinessResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ReadinessResponse]]:
        """Check if the model server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def ListModelDefinitions(
        self,
        request: model.model.v1alpha.model_definition_pb2.ListModelDefinitionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse, collections.abc.Awaitable[model.model.v1alpha.model_definition_pb2.ListModelDefinitionsResponse]]:
        """List model definitions

        Returns a paginated list of model definitions.
        """
    @abc.abstractmethod
    def ListAvailableRegions(
        self,
        request: model.model.v1alpha.model_pb2.ListAvailableRegionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListAvailableRegionsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListAvailableRegionsResponse]]:
        """List available regions

        Returns a paginated list of available regions.
        """
    @abc.abstractmethod
    def GetModelDefinition(
        self,
        request: model.model.v1alpha.model_definition_pb2.GetModelDefinitionRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse, collections.abc.Awaitable[model.model.v1alpha.model_definition_pb2.GetModelDefinitionResponse]]:
        """Get a model definition

        Returns the details of a model definition.
        """
    @abc.abstractmethod
    def ListModels(
        self,
        request: model.model.v1alpha.model_pb2.ListModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListModelsResponse]]:
        """List models

        Returns a paginated list of models.
        """
    @abc.abstractmethod
    def LookUpModel(
        self,
        request: model.model.v1alpha.model_pb2.LookUpModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.LookUpModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.LookUpModelResponse]]:
        """Get a model by UID

        Returns the details of a model by a permalink defined by the resource UID.
        """
    @abc.abstractmethod
    def ListNamespaceModels(
        self,
        request: model.model.v1alpha.model_pb2.ListNamespaceModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListNamespaceModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListNamespaceModelsResponse]]:
        """List namespace models

        Returns a paginated list of models.
        """
    @abc.abstractmethod
    def CreateNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.CreateNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateNamespaceModelResponse]]:
        """Create a new model

        Creates a new model under the parenthood of a namespace. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
    @abc.abstractmethod
    def GetNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.GetNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetNamespaceModelResponse]]:
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent namespace.
        """
    @abc.abstractmethod
    def UpdateNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.UpdateNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UpdateNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UpdateNamespaceModelResponse]]:
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent namespace and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
    @abc.abstractmethod
    def DeleteNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.DeleteNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteNamespaceModelResponse]]:
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model.
        """
    @abc.abstractmethod
    def RenameNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.RenameNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.RenameNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.RenameNamespaceModelResponse]]:
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model.
        """
    @abc.abstractmethod
    def WatchNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchNamespaceModelResponse]]:
        """Watch the state of a model version

        Returns the state of a model. The model resource allocation and scaling actions take some
        time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
    @abc.abstractmethod
    def WatchNamespaceLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchNamespaceLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchNamespaceLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchNamespaceLatestModelResponse]]:
        """Watch the state of the latest model version

        Returns the state of the latest model version. The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
    @abc.abstractmethod
    def ListNamespaceModelVersions(
        self,
        request: model.model.v1alpha.model_pb2.ListNamespaceModelVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListNamespaceModelVersionsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListNamespaceModelVersionsResponse]]:
        """List namespace model versions

        Returns a paginated list of version of a model namespace that belong to the specified namespace.
        Contains model version and digest.
        """
    @abc.abstractmethod
    def DeleteNamespaceModelVersion(
        self,
        request: model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteNamespaceModelVersionResponse]]:
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent namespace and the ID of the model, and version.
        """
    @abc.abstractmethod
    def TriggerNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerNamespaceModelResponse]]:
        """Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerAsyncNamespaceModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerAsyncNamespaceModelResponse]]:
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerNamespaceLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelResponse]]:
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerAsyncNamespaceLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerAsyncNamespaceLatestModelResponse]]:
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerNamespaceModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerNamespaceModelBinaryFileUploadResponse]]:
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
    @abc.abstractmethod
    def TriggerNamespaceLatestModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerNamespaceLatestModelBinaryFileUploadResponse]]:
        """Trigger model inference with a binary input

        Triggers the latest deployed model version to infer the result of a set of task or
        questions, submitted as a binary file.
        """
    @abc.abstractmethod
    def GetNamespaceModelOperation(
        self,
        request: model.model.v1alpha.model_pb2.GetNamespaceModelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetNamespaceModelOperationResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetNamespaceModelOperationResponse]]:
        """Get the details of the long-running operation from a namespace model
        with a particular version

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as trigger.
        """
    @abc.abstractmethod
    def GetNamespaceLatestModelOperation(
        self,
        request: model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetNamespaceLatestModelOperationResponse]]:
        """Get the details of the latest long-running operation from a namespace model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as trigger.
        """
    @abc.abstractmethod
    def GetModelOperation(
        self,
        request: model.model.v1alpha.model_pb2.GetModelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetModelOperationResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetModelOperationResponse]]:
        """Get the details of a long-running operation

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as trigger.
        """
    @abc.abstractmethod
    def ListUserModels(
        self,
        request: model.model.v1alpha.model_pb2.ListUserModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListUserModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListUserModelsResponse]]:
        """The following endpoints are all deprecated

        List user models

        Returns a paginated list of models that belong to the specified user. The
        parent user may be different from the authenticated user, in which case
        the results will contain the models that are visible to the latter.
        """
    @abc.abstractmethod
    def CreateUserModel(
        self,
        request: model.model.v1alpha.model_pb2.CreateUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateUserModelResponse]]:
        """Create a new model

        Creates a new model under the parenthood of a user. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
    @abc.abstractmethod
    def GetUserModel(
        self,
        request: model.model.v1alpha.model_pb2.GetUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetUserModelResponse]]:
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent user.
        """
    @abc.abstractmethod
    def UpdateUserModel(
        self,
        request: model.model.v1alpha.model_pb2.UpdateUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UpdateUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UpdateUserModelResponse]]:
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent user and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
    @abc.abstractmethod
    def DeleteUserModel(
        self,
        request: model.model.v1alpha.model_pb2.DeleteUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteUserModelResponse]]:
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
    @abc.abstractmethod
    def RenameUserModel(
        self,
        request: model.model.v1alpha.model_pb2.RenameUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.RenameUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.RenameUserModelResponse]]:
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent user and the ID of the model.
        """
    @abc.abstractmethod
    def WatchUserModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchUserModelResponse]]:
        """Watch the state of a model version

        Returns the state of a model. The model resource allocation and scaling actions take some
        time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
    @abc.abstractmethod
    def WatchUserLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchUserLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchUserLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchUserLatestModelResponse]]:
        """Watch the state of the latest model version

        Returns the state of the latest model version. The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
    @abc.abstractmethod
    def ListUserModelVersions(
        self,
        request: model.model.v1alpha.model_pb2.ListUserModelVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListUserModelVersionsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListUserModelVersionsResponse]]:
        """List user model versions

        Returns a paginated list of version of a model namespace that belong to the specified user.
        Contains model version and digest.
        """
    @abc.abstractmethod
    def DeleteUserModelVersion(
        self,
        request: model.model.v1alpha.model_pb2.DeleteUserModelVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteUserModelVersionResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteUserModelVersionResponse]]:
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent user and the ID of the model, and version.
        """
    @abc.abstractmethod
    def TriggerUserModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerUserModelResponse]]:
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerAsyncUserModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerAsyncUserModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerAsyncUserModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerAsyncUserModelResponse]]:
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerUserLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerUserLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerUserLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerUserLatestModelResponse]]:
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerAsyncUserLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerAsyncUserLatestModelResponse]]:
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerUserModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerUserModelBinaryFileUploadResponse]]:
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
    @abc.abstractmethod
    def ListOrganizationModels(
        self,
        request: model.model.v1alpha.model_pb2.ListOrganizationModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListOrganizationModelsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListOrganizationModelsResponse]]:
        """List organization models

        Returns a paginated list of models that belong to the specified organization. The
        parent organization may be different from the authenticated organization, in which case
        the results will contain the models that are visible to the latter.
        """
    @abc.abstractmethod
    def CreateOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.CreateOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.CreateOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.CreateOrganizationModelResponse]]:
        """Create a new model

        Creates a new model under the parenthood of an organization. This is an
        asynchronous endpoint, i.e., the server will not wait for the model to be
        created in order to respond. Instead, it will return a response with the
        necessary information to access the result and status of the creation
        operation.
        """
    @abc.abstractmethod
    def GetOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.GetOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetOrganizationModelResponse]]:
        """Get a model

        Returns the detail of a model, accessing it by the model ID and its parent organization.
        """
    @abc.abstractmethod
    def UpdateOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.UpdateOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.UpdateOrganizationModelResponse]]:
        """Update a model

        Updates a model, accessing it by its resource name, which is defined by
        the parent organization and the ID of the model.

        In REST requests, only the supplied model fields will be taken into
        account when updating the resource.
        """
    @abc.abstractmethod
    def DeleteOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.DeleteOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteOrganizationModelResponse]]:
        """Delete a model

        Deletes a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
    @abc.abstractmethod
    def RenameOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.RenameOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.RenameOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.RenameOrganizationModelResponse]]:
        """Rename a model

        Renames a model, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model.
        """
    @abc.abstractmethod
    def WatchOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchOrganizationModelResponse]]:
        """Watch the state of a model version

        Returns the state of a model.  The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
    @abc.abstractmethod
    def WatchOrganizationLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.WatchOrganizationLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.WatchOrganizationLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.WatchOrganizationLatestModelResponse]]:
        """Watch the state of the latest model version

        Returns the state of the latest model version.  The model resource allocation and scaling actions
        take some time, during which a model will be in various state. This endpoint
        allows clients to track the state.
        """
    @abc.abstractmethod
    def ListOrganizationModelVersions(
        self,
        request: model.model.v1alpha.model_pb2.ListOrganizationModelVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListOrganizationModelVersionsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListOrganizationModelVersionsResponse]]:
        """List organization model versions

        Returns a paginated list of version of a model namespace that belong to the specified organization.
        Contains model version and digest.
        """
    @abc.abstractmethod
    def DeleteOrganizationModelVersion(
        self,
        request: model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.DeleteOrganizationModelVersionResponse]]:
        """Delete a model version

        Deletes a model version, accesing it by its resource name, which is defined by the
        parent organization and the ID of the model, and version.
        """
    @abc.abstractmethod
    def TriggerOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerOrganizationModelResponse]]:
        """/////////////////////////////////////////////////////

        Trigger model inference

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerAsyncOrganizationModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerAsyncOrganizationModelResponse]]:
        """Trigger model inference asynchronously

        Triggers a deployed model to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerOrganizationLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerOrganizationLatestModelResponse]]:
        """Trigger model inference

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerAsyncOrganizationLatestModel(
        self,
        request: model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerAsyncOrganizationLatestModelResponse]]:
        """Trigger model inference asynchronously

        Triggers the latest deployed model version to infer the result of a set of task or
        questions.
        """
    @abc.abstractmethod
    def TriggerOrganizationModelBinaryFileUpload(
        self,
        request_iterator: _MaybeAsyncIterator[model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadRequest],
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.TriggerOrganizationModelBinaryFileUploadResponse]]:
        """Trigger model inference with a binary input

        Triggers a deployed model to infer the result of a task or question,
        submitted as a binary file.
        """
    @abc.abstractmethod
    def GetUserLatestModelOperation(
        self,
        request: model.model.v1alpha.model_pb2.GetUserLatestModelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetUserLatestModelOperationResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetUserLatestModelOperationResponse]]:
        """Get the details of the latest long-running operation from a user model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as trigger.
        """
    @abc.abstractmethod
    def GetOrganizationLatestModelOperation(
        self,
        request: model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.GetOrganizationLatestModelOperationResponse]]:
        """Get the details of the latest long-running operation from a organization model

        This method allows requesters to request the status and outcome of
        long-running operations in a model, such as trigger.
        """
    @abc.abstractmethod
    def ListModelRuns(
        self,
        request: model.model.v1alpha.model_pb2.ListModelRunsRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListModelRunsResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListModelRunsResponse]]:
        """List model runs

        Returns a paginated list of model runs.
        """
    @abc.abstractmethod
    def ListModelRunsByCreditOwner(
        self,
        request: model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerResponse, collections.abc.Awaitable[model.model.v1alpha.model_pb2.ListModelRunsByCreditOwnerResponse]]:
        """List Model Runs of a Namespace (user or organization)

        Returns a paginated list of runs for 1 or more models. This is mainly used by credit dashboard.
        The requester can view all the runs that consumed their credits across different models.
        """

def add_ModelPublicServiceServicer_to_server(servicer: ModelPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
